==> sflphone_1.1.0.orig.tar.gz: sflphone-1.1.0/daemon/src/dbus/dbusmanager.h <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef __DBUSMANAGERIMPL_H__
#define __DBUSMANAGERIMPL_H__

#include "dbus_cpp.h"
#include "noncopyable.h"

class ConfigurationManager;
class CallManager;
class NetworkManager;
class Instance;

class DBusManager {
    public:
        DBusManager();
        ~DBusManager();

        CallManager * getCallManager() {
            return callManager_;
        };
        ConfigurationManager * getConfigurationManager() {
            return configurationManager_;
        };

        void exec();
        void exit();

    private:
        NON_COPYABLE(DBusManager);
        CallManager*          callManager_;
        ConfigurationManager* configurationManager_;
        Instance*             instanceManager_;
        DBus::BusDispatcher   dispatcher_;
#if USE_NETWORKMANAGER
        NetworkManager* networkManager_;
#endif
};

#endif

==> sflphone_1.2.0.orig.tar.gz: sflphone-1.2.0/daemon/src/dbus/dbusmanager.h <==
/*
 *  Copyright (C) 2004, 2005, 2006, 2008, 2009, 2010, 2011 Savoir-Faire Linux Inc.
 *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Additional permission under GNU GPL version 3 section 7:
 *
 *  If you modify this program, or any covered work, by linking or
 *  combining it with the OpenSSL project's OpenSSL library (or a
 *  modified version of that library), containing parts covered by the
 *  terms of the OpenSSL or SSLeay licenses, Savoir-Faire Linux Inc.
 *  grants you additional permission to convey the resulting work.
 *  Corresponding Source for a non-source form of such a combination
 *  shall include the source code for the parts of OpenSSL used as well
 *  as that of the covered work.
 */

#ifndef __DBUSMANAGERIMPL_H__
#define __DBUSMANAGERIMPL_H__

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif
#include "dbus_cpp.h"
#include "noncopyable.h"

class ConfigurationManager;
class CallManager;
class NetworkManager;
class Instance;
class VideoControls;

class DBusManager {
    public:
        DBusManager();
        ~DBusManager();

        CallManager * getCallManager() {
            return callManager_;
        }
        ConfigurationManager * getConfigurationManager() {
            return configurationManager_;
        }
#ifdef SFL_VIDEO
        VideoControls* getVideoControls() {
            return videoControls_;
        }
#endif

        void exec();
        void exit();

    private:
        NON_COPYABLE(DBusManager);
        CallManager*          callManager_;
        ConfigurationManager* configurationManager_;
        Instance*             instanceManager_;
        DBus::BusDispatcher   dispatcher_;
#ifdef SFL_VIDEO
        VideoControls *videoControls_;
#endif
#if USE_NETWORKMANAGER
        NetworkManager* networkManager_;
#endif
};

#endif
